sdkTool method
Returns the path to a tool from the Dart/Flutter SDK.
If no sdkPath is specified, this will return the name of the tool
as is so that it can be used as an executable from
EnvironmentVariableKey.path.
Implementation
String sdkTool(String tool) {
final sdkPath = this.sdkPath;
if (sdkPath != null) {
return p.join(sdkPath, 'bin', tool);
}
return tool;
}